
###########################################################################################################################################
################################################################ Presence models ##########################################################
###########################################################################################################################################

###Set wd


##Transform DF into community matrix
library(reshape)
CM_df <- read.csv("Troglobites_taxa.csv", head=T)
CM_df2 <- cast(CM_df, CAVE.ID ~ Species, value="Count", sum) 
CM_df2 <- as.data.frame(CM_df2)
row.names(CM_df2) <- CM_df2$ID

###Subset by Cavedata-R7_TrogRSubset_pd.csv
C <- read.csv("TrogData_final.csv", header=T, na.strings = "NA") 

Min <- aggregate(Altitude ~ Highland, data = C, min)
Max <- aggregate(Altitude ~ Highland, data = C, max)
HA <- cbind(Min,Max)
HA <- HA[ , c(1,2,4)]
colnames(HA) <- c("Highland", "minA", "maxA")
HA$dif <- HA$maxA - HA$minA
HA
  
row.names(C) <- C$ID
CM_df3 <- merge(CM_df2, C, by="row.names", all=FALSE)
CM_df3 <- droplevels(CM_df3)
row.names(CM_df3) <- CM_df3$Row.names
head(CM_df3)
CM_df3$ID.x == CM_df3$ID.y
head(CM_df3)

### Community matrix
names(CM_df3)
CM_df5 <- CM_df3[ , c(3:135)]
min(colSums(CM_df5))
CM_df5 <- droplevels(CM_df5)
CM_df5[CM_df5 >= 1 ] <- 1 ## Dataframe: Transform abundance into presence/absence data
head(CM_df5)
dim(CM_df5)

###Subset by the most abundant species
hist(colSums(CM_df5), breaks=100)
hist(colSums(CM_df5), xlim=c(0,50), breaks=50)

AB <- CM_df5[ colSums(CM_df5)>=4, ]
min(rowSums(AB))
AB <- droplevels(AB)
nrow(AB)

RAR <- CM_df5[ colSums(CM_df5)<=3, ]
min(rowSums(RAR))
RAR <- droplevels(RAR)
nrow(RAR)
nrow(AB) + nrow(RAR)

head(AB)
head(RAR)
row.names(RAR) == row.names(AB)

### Append landscape data
names(CM_df3)
LAN <- CM_df3[ , c(136:258)]

AB.LAN <- merge(AB, LAN, by="row.names", all=FALSE)
AB.LAN <- droplevels(AB.LAN)
AB.LAN$TrogType <- c("Abundant")

RAR.LAN <- merge(RAR, LAN, by="row.names", all=FALSE)
RAR.LAN <- droplevels(RAR.LAN)
RAR.LAN$TrogType <- c("Rare")

ALL.LAN <- rbind(AB.LAN, RAR.LAN)
dim(ALL.LAN)
head(ALL.LAN)

## Bias models
library(lme4)
library(lmerTest)
source("~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/overdisp_fun.R")
names(ALL.LAN)

TR1 <- glmer(TR ~ scale(MINING_50, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=poisson)
TR2 <- glmer(TR ~ scale(MINING_100, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=poisson)
TR3 <- glmer(TR ~ scale(MINING_250, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=poisson)
TR4 <- glmer(TR ~ scale(MINING_500, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=poisson)

overdisp_fun(TR1)
write.csv(rbind(summary(TR1)$coeff[2,], summary(TR2)$coeff[2,], summary(TR3)$coeff[2,], summary(TR4)$coeff[2,]), file="TRmodels.csv", row.names=F)

Trog1 <- glmer(TrogRich ~ scale(MINING_50, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=poisson)
Trog2 <- glmer(TrogRich ~ scale(MINING_100, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=poisson)
Trog3 <- glmer(TrogRich ~ scale(MINING_250, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=poisson)
Trog4 <- glmer(TrogRich ~ scale(MINING_500, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=poisson)

overdisp_fun(Trog1)
write.csv(rbind(summary(Trog1)$coeff[2,], summary(Trog2)$coeff[2,], summary(Trog3)$coeff[2,], summary(Trog4)$coeff[2,]), file="Trogmodels.csv", row.names=F)

ALL.LAN$TrogType2 <- ifelse(ALL.LAN$TrogType=="Rare", 1, 0)
RAR1 <- glmer(TrogType2 ~ scale(MINING_50, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=binomial)
RAR2 <- glmer(TrogType2 ~ scale(MINING_100, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=binomial)
RAR3 <- glmer(TrogType2 ~ scale(MINING_250, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=binomial)
RAR4 <- glmer(TrogType2 ~ scale(MINING_500, scale=T, center=T) + (1|Highland) + (1|Row.names), data=ALL.LAN, family=binomial)

overdisp_fun(RAR1)
write.csv(rbind(summary(RAR1)$coeff[2,], summary(RAR2)$coeff[2,], summary(RAR3)$coeff[2,], summary(RAR4)$coeff[2,]), file="RARmodels.csv", row.names=F)


