#################################################################### Circuitscape
## Install Circuitscape: https://pypi.python.org/pypi/Circuitscape/
## Download and load runCS function: https://github.com/rojaff/runCS
## Run CS
runCS(coordinates="Cave_coords_utm.txt", raster="LU_R_Cr.asc")
runCS(coordinates="Cave_coords_utm.txt", raster="LU_R_Cr_Geo.asc")
runCS(coordinates="Cave_coords_utm.txt", raster="Roug4.asc")
runCS(coordinates="Cave_coords_utm.txt", raster="DemI4.asc")

############### Load Resistance distances from CS
setwd("~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Circuitscape")
LCR <- read.table("~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Circuitscape/LU_R_Cr_resistances_3columns.out", header=F, sep="")
colnames(LCR ) <- c("ID1", "ID2", "LCR")
LCR <- LCR[!LCR$ID2==LCR$ID1,]
LCR2  <- LCR[order(LCR$ID1, LCR$ID2),] 
head(LCR2)

GD <- read.table("~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Circuitscape/LU_R_Cr_Geo_resistances_3columns.out", header=F, sep="")
colnames(GD ) <- c("ID1", "ID2", "GD")
GD <- GD[!GD$ID2==GD$ID1,]
GD2  <- GD[order(GD$ID1, GD$ID2),] 
#GD <- GD[!GD$ID1==GD$ID2 & !GD$ID2<GD$ID1,]
head(GD2)

DEMI <- read.table("~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Circuitscape/DemI4_resistances_3columns.out", header=F, sep="")
colnames(DEMI ) <- c("ID1", "ID2", "DEMI")
DEMI <- DEMI[!DEMI$ID2==DEMI$ID1,]
DEMI2  <- DEMI[order(DEMI$ID1, DEMI$ID2),] 
head(DEMI2)

RUG <- read.table("~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Circuitscape/Roug4_resistances_3columns.out", header=F, sep="")
colnames(RUG ) <- c("ID1", "ID2", "RUG")
RUG <- RUG[!RUG$ID2==RUG$ID1,]
RUG2  <- RUG[order(RUG$ID1, RUG$ID2),] 
head(RUG2)

nrow(LCR2)
nrow(GD2)
nrow(DEMI2)
nrow(RUG2)

###################Dissimilarity distances

##Transform DF into community matrix
library(reshape)
library(vegan)
library(reshape2)

##Transform DF into community matrix
CM_df <- read.csv("Troglobites_taxa.csv", head=T)
CM_df2 <- cast(CM_df, ID ~ Species, value="N", sum) 
CM_df2 <- as.data.frame(CM_df2)
row.names(CM_df2) <- CM_df2$ID

###Final Community matrix
names(CM_df2)
CM_df3 <- CM_df2[ , c(2:134)]
#min(colSums(CM_df4))
#CM_df4 <- CM_df4[, colSums(CM_df4)>=1] 
CM_df3 <- droplevels(CM_df3)
CM_df3[CM_df3 >= 1 ] <- 1 ## Dataframe: Transform abundance into presence/absence data

CM <- data.matrix(CM_df3) 
#CM[CM>0] <- 1 ## Matrix: Transform abundance into presence/absence data

###########Calculate Dissimilarity distance
dist <- vegdist(CM, method="bray", binary=TRUE) #Bray = Sorensen index -> Based on presence/absence data.
dist_df <- melt(as.matrix(dist), varnames = c("row", "col"))
dist_df  <- dist_df[order(dist_df$row, dist_df$col),] 
dist_df2 <- dist_df[!dist_df$col==dist_df$row & !dist_df$col<dist_df$row,]
colnames(dist_df2) <- c("row" ,  "col" ,  "BC_dis")

head(dist_df2)
nrow(dist_df2)

##Build dataframe with all Distances 
DT <- data.frame(GD2, LCR2[3], DEMI2[3], RUG2[3], dist_df2[3]) 
DT$ID1 <- factor(DT$ID1)
DT$ID2 <- factor(DT$ID2)
str(DT)

######################################################################## MLPE
## Install corMLPE from GitHub: https://github.com/nspope/corMLPE

library(corMLPE)
library(nlme)
library(MuMIn)

cor(DT[ , c(3:6)]) ##All collinear
plot(DT$GD, DT$LCR)
head(DT)

M1 <- gls(BC_dis ~ GD, correlation = corMLPE(form = ~ ID1 + ID2), data = DT, method = "ML")
M2 <- gls(BC_dis ~ LCR, correlation = corMLPE(form = ~ ID1 + ID2), data = DT, method = "ML")
M3 <- gls(BC_dis ~ DEMI, correlation = corMLPE(form = ~ ID1 + ID2), data = DT, method = "ML")
M4 <- gls(BC_dis ~ RUG, correlation = corMLPE(form = ~ ID1 + ID2), data = DT, method = "ML")
MS <- as.data.frame(model.sel(M1, M2, M3, M4))

write.csv(MS, file="MS.csv", row.names=T)
summary(M1)

####################### Plot decorrelated residuals
library(ggplot2)
library(gridExtra)

pr.norm.singlecov = function(object){
  val <- object[["residuals"]]
  fit <- fitted(object) 
  rawfit <- fit
  raw <- resid(object) + fit
  fit <- fit/attr(val, "std")
  val <- val/attr(val, "std")
  cSt <- object$modelStruct$corStruct
  val <- corMLPE:::recalc.corMLPE(cSt, list(Xy = as.matrix(val)))$Xy
  return(data.frame(pr=fit+val,fit=fit,raw=raw,rawfit=rawfit))
}

goo <- pr.norm.singlecov(M1)

Rplot_decor <- ggplot(data.frame(goo,covar=DT$GD), aes(x = covar)) + geom_point(aes(y=pr), alpha=0.5) + geom_line(aes(y=fit), size=1) +
ylab("Dissimilarity distance (Bray-Curtis)") + 
  xlab("Resistance distance (geographic distance)") + 
  theme_minimal() + theme(axis.title.y = element_text(size=15, color = "black", face = "bold"),
                          axis.title.x = element_text(size=15, color = "black", face = "bold"))

tiff(filename = "/home/rodolfojaffe/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Figs/Rplot_decor.tif",
     width = 20, height = 20, units = "cm", ##Fig2: 35x18
     compression = "lzw", bg = "white", res = 300)

Rplot_decor
dev.off()

