
###########################################################################################################################################
################################################################ LANDSCAPE MODELS ##########################################################
###########################################################################################################################################

###Load data
CAV <- read.csv("TrogData_final.csv", head=T, na.string="NA") ## _edit contains Highland instead of Report
CAV <- CAV[complete.cases(CAV), ]
CAV$ID <- factor(CAV$ID)
names(CAV)
str(CAV)
nrow(CAV)

summary(CAV) ##Remove: Veg, Root, RB, Car, BATPOP

######################################### PCAs
### Size
names(CAV)
PC <- princomp( scale(CAV[, c(6, 8, 9)]))
plot(PC)
PC1 <- PC$scores[, 1]
cor(CAV$HP, PC1)
cor(CAV$Area, PC1) ##Area
cor(CAV$Volume, PC1)

#Geomorphology
names(CAV)
names(CAV[ , c(71:78)])
PC_50 <- princomp(CAV[ , c(47:54)])
PC_100 <- princomp(CAV[ , c(55:62)])
PC_250 <- princomp(CAV[ , c(63:70)])
PC_500 <- princomp(CAV[ , c(71:78)])

biplot(PC_50, xlim=c(-0.10, 0.1)); loadings(PC_50)
biplot(PC_100); loadings(PC_100)
biplot(PC_250); loadings(PC_250)
biplot(PC_500); loadings(PC_500)

#Lithology
names(CAV)
names(CAV[ , c(117:122)])
PC2_50 <- princomp(CAV[ , c(99:104)])
PC2_100 <- princomp(CAV[ , c(105:110)])
PC2_250 <- princomp(CAV[ , c(111:116)])
PC2_500 <- princomp(CAV[ , c(117:122)])

biplot(PC2_50, xlim=c(-0.15, 0.1)); loadings(PC2_50)
biplot(PC2_100); loadings(PC2_100)
biplot(PC2_250); loadings(PC2_250)
biplot(PC2_500); loadings(PC2_500)

#tiff(filename = "~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Figs/PCA_geomorphology.tif",
#     width = 20, height = 20, units = "cm",
#     compression = "lzw", bg = "white", res = 300)

#dev.off()

CAV$PC_50a <- PC_50$scores[,1]
CAV$PC_100a <- PC_100$scores[,1]
CAV$PC_250a <- PC_250$scores[,1]
CAV$PC_500a <- PC_500$scores[,1]
CAV$PC_50b <- PC_50$scores[,2]
CAV$PC_100b <- PC_100$scores[,2]
CAV$PC_250b <- PC_250$scores[,2]
CAV$PC_500b <- PC_500$scores[,2]

CAV$PC2_50a <- PC2_50$scores[,1]
CAV$PC2_100a <- PC2_100$scores[,1]
CAV$PC2_250a <- PC2_250$scores[,1]
CAV$PC2_500a <- PC2_500$scores[,1]
CAV$PC2_50b <- PC2_50$scores[,2]
CAV$PC2_100b <- PC2_100$scores[,2]
CAV$PC2_250b <- PC2_250$scores[,2]
CAV$PC2_500b <- PC2_500$scores[,2]

######################################## Functions
library(lme4); library(MuMIn); library(MASS); library(lmerTest)

Bscale <- function(response, predictor1, predictor2, predictor3, predictor4, dataset){
  formula1 <- paste(response, "~", predictor1, "+", "(1|Highland)")
  formula2 <- paste(response, "~", predictor2, "+", "(1|Highland)")
  formula3 <- paste(response, "~", predictor3, "+", "(1|Highland)")
  formula4 <- paste(response, "~", predictor4, "+", "(1|Highland)")
  M1 <- lmer(formula1, data=dataset, REML=F)
  M2 <- lmer(formula2, data=dataset, REML=F)
  M3 <- lmer(formula3, data=dataset, REML=F)
  M4 <- lmer(formula4, data=dataset, REML=F)
  MS <- model.sel(M1, M2, M3, M4, rank="AIC") 
  return(MS)
}

Bscale2 <- function(response, predictor1, predictor2, dataset){
  formula1 <- paste(response, "~", predictor1, "+", "(1|Highland)")
  formula2 <- paste(response, "~", predictor2, "+", "(1|Highland)")
  M1 <- lmer(formula1, data=dataset, REML=F)
  M2 <- lmer(formula2, data=dataset, REML=F)
  MS <- model.sel(M1, M2, rank="AIC") 
  return(MS)
}

Bscale.glm <- function(response, predictor1, predictor2, predictor3, predictor4, dataset){
  formula1 <- paste(response, "~", "scale(", predictor1, ", scale=T)", "+", "(1|Highland)", "+", "(1|ID)")
  formula2 <- paste(response, "~", "scale(", predictor2, ", scale=T)", "+", "(1|Highland)", "+", "(1|ID)")
  formula3 <- paste(response, "~", "scale(", predictor3, ", scale=T)", "+", "(1|Highland)", "+", "(1|ID)")
  formula4 <- paste(response, "~", "scale(", predictor4, ", scale=T)", "+", "(1|Highland)", "+", "(1|ID)")
  cont=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))
  M1 <- glmer(formula1, data=dataset, family=poisson, control=cont)
  M2 <- glmer(formula2, data=dataset, family=poisson, control=cont)
  M3 <- glmer(formula3, data=dataset, family=poisson, control=cont)
  M4 <- glmer(formula4, data=dataset, family=poisson, control=cont)
  MS <- model.sel(M1, M2, M3, M4, rank="AIC") 
  return(MS)
}

Bscale2.glm <- function(response, predictor1, predictor2, dataset){
  formula1 <- paste(response, "~", "scale(", predictor1, ", scale=T)", "+", "(1|Highland)", "+", "(1|ID)")
  formula2 <- paste(response, "~", "scale(", predictor2, ", scale=T)", "+", "(1|Highland)", "+", "(1|ID)")
  cont=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))
  M1 <- glmer(formula1, data=dataset, family=poisson, control=cont)
  M2 <- glmer(formula2, data=dataset, family=poisson, control=cont)
  MS <- model.sel(M1, M2, rank="AIC") 
  return(MS)
}

### Function to calculate maximum correlation coefficient between predictor variables, retrieved from each model
max.r <- function(x){
  corm <- cov2cor(vcov(x))
  corm <- as.matrix(corm)
  if (length(corm)==1){
    corm <- 0
    max(abs(corm))
  } else if (length(corm)==4){
    cormf <- corm[2:nrow(corm),2:ncol(corm)]
    cormf <- 0
    max(abs(cormf))
  } else {
    cormf <- corm[2:nrow(corm),2:ncol(corm)]
    diag(cormf) <- 0
    max(abs(cormf))
  }
}

############################################################ MDS1
##Landscape Vars
Bscale("MDS1", "area_vs_buff50", "area_vs_buff100", "area_vs_buff250", "area_vs_buff500", CAV) #area_vs_buff500
Bscale("MDS1", "DCL_0_10B50", "DCL_0_10B100", "DCL_0_10B250", "DCL_0_10B500", CAV) #DCL_0_10B500
Bscale("MDS1", "DCL_10_20B50", "DCL_10_20B100", "DCL_10_20B250", "DCL_10_20B500", CAV) #DCL_10_20B500
Bscale("MDS1", "DCL_20_30B50", "DCL_20_30B100", "DCL_20_30B250", "DCL_20_30B500", CAV) #DCL_20_30B250
Bscale2("MDS1", "scale(DCL_30_40B250, scale=T)", "scale(DCL_30_40B500, scale=T)", CAV) #DCL_30_40B250
Bscale("MDS1", "dens_50_km2", "dens_100_km2", "dens_250_km2", "dens_500_km2", CAV) #dens_500_km2
Bscale("MDS1", "PC_50a", "PC_100a", "PC_250a", "PC_500a", CAV) #PC_500a
Bscale("MDS1", "PC_50b", "PC_100b", "PC_250b", "PC_500b", CAV) #PC_500b
Bscale("MDS1", "PC2_50a", "PC2_100a", "PC2_250a", "PC2_500a", CAV) #PC2_500a
Bscale("MDS1", "PC2_50b", "PC2_100b", "PC2_250b", "PC2_500b", CAV) #PC2_500b
Bscale("MDS1", "BPA_50", "BPA_100", "BPA_250", "BPA_500", CAV) #BPA_50
Bscale("MDS1", "FOREST_50", "FOREST_100", "FOREST_250", "FOREST_500", CAV) ##FOREST_50
Bscale("MDS1", "MINING_50", "MINING_100", "MINING_250", "MINING_500", CAV) ##MINING_250
Bscale("MDS1", "MONTSAV_50", "MONTSAV_100", "MONTSAV_250", "MONTSAV_500", CAV) ##MONTSAV_50

Com1 <- lmer(MDS1 ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff500, scale=T) + 
               scale(DCL_0_10B500, scale=T) + scale(DCL_10_20B500, scale=T) + scale(DCL_20_30B250, scale=T) + scale(DCL_30_40B250, scale=T) +
               scale(dens_500_km2, scale=T) + scale(PC_500a, scale=T) + scale(PC_500b, scale=T) + scale(PC2_500a, scale=T) + scale(PC2_500b, scale=T) +
               scale(BPA_50, scale=T) + scale(FOREST_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + (1|Highland), data=CAV, REML=F)

max.r(Com1)
COR <- abs(cov2cor(vcov(Com1))) ##Removed: scale(FOREST_500, scale=T), scale(DCL_10_20B500, scale = T), scale(dens_500_km2, scale=T)
COR>=0.97&COR<1
COR

Com1b <- lmer(MDS1 ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff500, scale=T) + 
               scale(DCL_0_10B500, scale=T) + scale(DCL_20_30B250, scale=T) + scale(DCL_30_40B250, scale=T) +
                scale(PC_500a, scale=T) + scale(PC_500b, scale=T) + scale(PC2_500a, scale=T) + scale(PC2_500b, scale=T) +
               scale(BPA_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + (1|Highland), data=CAV, REML=F)

max.r(Com1b)
COR <- abs(cov2cor(vcov(Com1b))) ##Removed: scale(FOREST_500, scale=T), scale(DCL_10_20B500, scale = T)
COR>=0.75&COR<1
COR

##Add Cave variables
Com1_cave <- lmer(MDS1 ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff500, scale=T) + 
                scale(DCL_0_10B500, scale=T) + scale(DCL_20_30B250, scale=T) + scale(DCL_30_40B250, scale=T) +
                scale(PC_500a, scale=T) + scale(PC_500b, scale=T) + scale(PC2_500a, scale=T) + scale(PC2_500b, scale=T) +
                scale(BPA_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + 
                scale(Altitude, scale=T) + scale(Area, scale=T)  + PW  + WR + Det + Guano + Ofez + (1|Highland), data=CAV, REML=F)

max.r(Com1_cave)
drop1(Com1_cave, test="Chisq")

Com1.bm <- lmer(MDS1 ~ scale(area_vs_buff500, scale=T) + scale(DCL_0_10B500, scale = T) + scale(MINING_250, scale = T) + (1|Highland), data=CAV, REML=T)
summary(Com1.bm)

################################################ MDS2
##Landscape Vars
Bscale("MDS2", "area_vs_buff50", "area_vs_buff100", "area_vs_buff250", "area_vs_buff500", CAV) #area_vs_buff100
Bscale("MDS2", "DCL_0_10B50", "DCL_0_10B100", "DCL_0_10B250", "DCL_0_10B500", CAV) #DCL_0_10B100
Bscale("MDS2", "DCL_10_20B50", "DCL_10_20B100", "DCL_10_20B250", "DCL_10_20B500", CAV) #DCL_10_20B100
Bscale("MDS2", "DCL_20_30B50", "DCL_20_30B100", "DCL_20_30B250", "DCL_20_30B500", CAV) #DCL_20_30B500
Bscale2("MDS2", "scale(DCL_30_40B250, scale=T)", "scale(DCL_30_40B500, scale=T)", CAV) #DCL_30_40B500
Bscale("MDS2", "dens_50_km2", "dens_100_km2", "dens_250_km2", "dens_500_km2", CAV) #dens_50_km2
Bscale("MDS2", "PC_50a", "PC_100a", "PC_250a", "PC_500a", CAV) #PC_50a
Bscale("MDS2", "PC_50b", "PC_100b", "PC_250b", "PC_500b", CAV) #PC_500b
Bscale("MDS2", "PC2_50a", "PC2_100a", "PC2_250a", "PC2_500a", CAV) #PC2_50a
Bscale("MDS2", "PC2_50b", "PC2_100b", "PC2_250b", "PC2_500b", CAV) #PC2_50b
Bscale("MDS2", "BPA_50", "BPA_100", "BPA_250", "BPA_500", CAV) #BPA_100
Bscale("MDS2", "FOREST_50", "FOREST_100", "FOREST_250", "FOREST_500", CAV) ##FOREST_50
Bscale("MDS2", "MINING_50", "MINING_100", "MINING_250", "MINING_500", CAV) ##MINING_50
Bscale("MDS2", "MONTSAV_50", "MONTSAV_100", "MONTSAV_250", "MONTSAV_500", CAV) ##MONTSAV_50

Com2 <- lmer(MDS2 ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff100, scale=T) + 
               scale(DCL_0_10B100, scale=T) + scale(DCL_10_20B100, scale=T) + scale(DCL_20_30B500, scale=T) + scale(DCL_30_40B500, scale=T) +
               scale(dens_50_km2, scale=T) + scale(PC_50a, scale=T) + scale(PC_500b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_50b, scale=T) +
               scale(BPA_100, scale=T) + scale(FOREST_50, scale=T) + scale(MINING_50, scale=T) + scale(MONTSAV_50, scale=T) + (1|Highland), data=CAV, REML=F)

max.r(Com2)
COR <- abs(cov2cor(vcov(Com2))) ##Removed: scale(FOREST_50, scale=T), scale(DCL_10_20B100, scale=T) 
COR>=0.9&COR<1
COR

Com2b <- lmer(MDS2 ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff100, scale=T) + 
               scale(DCL_0_10B100, scale=T) + scale(DCL_20_30B500, scale=T) + scale(DCL_30_40B500, scale=T) +
               scale(dens_50_km2, scale=T) + scale(PC_50a, scale=T) + scale(PC_500b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_50b, scale=T) +
               scale(BPA_100, scale=T) + scale(MINING_50, scale=T) + scale(MONTSAV_50, scale=T) + (1|Highland), data=CAV, REML=F)

max.r(Com2b)
COR <- abs(cov2cor(vcov(Com2b))) ##Removed: scale(FOREST_50, scale=T)
COR>=0.7&COR<1
COR

##Add Cave variables
Com2_cave <- lmer(MDS2 ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff100, scale=T) + 
                scale(DCL_0_10B100, scale=T) + scale(DCL_20_30B500, scale=T) + scale(DCL_30_40B500, scale=T) +
                scale(dens_50_km2, scale=T) + scale(PC_50a, scale=T) + scale(PC_500b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_50b, scale=T) +
                scale(BPA_100, scale=T) + scale(MINING_50, scale=T) + scale(MONTSAV_50, scale=T) + 
                scale(Altitude, scale=T) + scale(Area, scale=T)  + PW  + WR + Det + Guano + Ofez + (1|Highland), data=CAV, REML=F)

max.r(Com2_cave)
drop1(Com2_cave, test="Chisq") 

Com2.bm <- lmer(MDS2 ~ scale(DCL_30_40B500, scale = T) + scale(dens_50_km2, scale = T) + scale(PC2_50b, scale = T) + scale(MONTSAV_50, scale = T) + 
                  scale(Altitude, scale = T) + (1|Highland), data=CAV, REML=T)
summary(Com2.bm)
biplot(PC2_50); loadings(PC2_50) #SSLOPE_500, HSHARP_500, HCONV_500, HTAB_500

###################################################################### Richness
##Landscape Vars
Bscale.glm("TrogRich", "area_vs_buff50", "area_vs_buff100", "area_vs_buff250", "area_vs_buff500", CAV) #area_vs_buff50
Bscale.glm("TrogRich", "DCL_0_10B50", "DCL_0_10B100", "DCL_0_10B250", "DCL_0_10B500", CAV) #DCL_0_10B250
Bscale.glm("TrogRich", "DCL_10_20B50", "DCL_10_20B100", "DCL_10_20B250", "DCL_10_20B500", CAV) #DCL_10_20B100
Bscale.glm("TrogRich", "DCL_20_30B50", "DCL_20_30B100", "DCL_20_30B250", "DCL_20_30B500", CAV) #DCL_20_30B250
Bscale2.glm("TrogRich", "DCL_30_40B250", "DCL_30_40B500", CAV) #DCL_30_40B250
Bscale.glm("TrogRich", "dens_50_km2", "dens_100_km2", "dens_250_km2", "dens_500_km2", CAV) #dens_50_km2
Bscale.glm("TrogRich", "PC_50a", "PC_100a", "PC_250a", "PC_500a", CAV) #PC_100a
Bscale.glm("TrogRich", "PC_50b", "PC_100b", "PC_250b", "PC_500b", CAV) #PC_50b
Bscale.glm("TrogRich", "PC2_50a", "PC2_100a", "PC2_250a", "PC2_500a", CAV) #PC2_50a
Bscale.glm("TrogRich", "PC2_50b", "PC2_100b", "PC2_250b", "PC2_500b", CAV) #PC2_500b
Bscale.glm("TrogRich", "BPA_50", "BPA_100", "BPA_250", "BPA_500", CAV) #BPA_50
Bscale.glm("TrogRich", "FOREST_50", "FOREST_100", "FOREST_250", "FOREST_500", CAV) ##FOREST_50
Bscale.glm("TrogRich", "MINING_50", "MINING_100", "MINING_250", "MINING_500", CAV) ##MINING_250
Bscale.glm("TrogRich", "MONTSAV_50", "MONTSAV_100", "MONTSAV_250", "MONTSAV_500", CAV) ##MONTSAV_50

cont=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))
Rich <- glmer(TrogRich ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
                scale(DCL_0_10B250, scale=T) + scale(DCL_10_20B100, scale=T) + scale(DCL_20_30B250, scale=T) + scale(DCL_30_40B250, scale=T) +
                scale(dens_50_km2, scale=T) + scale(PC_100a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_500b, scale=T) +
                scale(BPA_50, scale=T) + scale(FOREST_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + 
                (1|Highland) + (1|ID), data=CAV, family="poisson", control=cont)

source("overdisp_fun.R")
overdisp_fun(Rich)

max.r(Rich)
COR <- abs(cov2cor(vcov(Rich))) ##Removed:  scale(DCL_20_30B250, scale=T), scale(FOREST_50, scale=T) 
COR>=0.8&COR<1
COR

Rich2 <- glmer(TrogRich ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
                scale(DCL_0_10B250, scale=T) + scale(DCL_10_20B100, scale=T) + scale(DCL_30_40B250, scale=T) +
                scale(dens_50_km2, scale=T) + scale(PC_100a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_500b, scale=T) +
                scale(BPA_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + 
                (1|Highland) + (1|ID), data=CAV, family="poisson", control=cont)

max.r(Rich2)
COR <- abs(cov2cor(vcov(Rich2))) #
COR>=0.8&COR<1
COR

##Add Cave variables
cont=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))
Rich_cave <- glmer(TrogRich ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
                 scale(DCL_0_10B250, scale=T) + scale(DCL_10_20B100, scale=T) + scale(DCL_30_40B250, scale=T) +
                 scale(dens_50_km2, scale=T) + scale(PC_100a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_500b, scale=T) +
                 scale(BPA_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + 
                 scale(Altitude, scale=T) + scale(Area, scale=T) + PW  + WR + Det + Guano + Ofez +
                 (1|Highland) + (1|ID), data=CAV, family="poisson", control=cont)

max.r(Rich_cave) ##Omitted (r=0.63)
drop1(Rich_cave, test="Chisq")

Rich.bm <- glmer(TrogRich ~ scale(dist_dreinage, scale = T) + scale(PC_50b, scale = T) + scale(BPA_50, scale = T) + scale(Area, scale = T) + Guano +
                   (1|Highland) + (1|ID), data=CAV, family="poisson", control=cont)

summary(Rich.bm)
biplot(PC_50); loadings(PC_50)

######################################################################## Philogenetic Diversity
##Landscape Vars
Bscale("pd.obs", "area_vs_buff50", "area_vs_buff100", "area_vs_buff250", "area_vs_buff500", CAV) #area_vs_buff50
Bscale("pd.obs", "DCL_0_10B50", "DCL_0_10B100", "DCL_0_10B250", "DCL_0_10B500", CAV) #DCL_0_10B250
Bscale("pd.obs", "DCL_10_20B50", "DCL_10_20B100", "DCL_10_20B250", "DCL_10_20B500", CAV) #DCL_10_20B100
Bscale("pd.obs", "DCL_20_30B50", "DCL_20_30B100", "DCL_20_30B250", "DCL_20_30B500", CAV) #DCL_20_30B250
Bscale2("pd.obs", "DCL_30_40B250", "DCL_30_40B500", CAV) #DCL_30_40B500
Bscale("pd.obs", "dens_50_km2", "dens_100_km2", "dens_250_km2", "dens_500_km2", CAV) #dens_50_km2
Bscale("pd.obs", "PC_50a", "PC_100a", "PC_250a", "PC_500a", CAV) #PC_100a
Bscale("pd.obs", "PC_50b", "PC_100b", "PC_250b", "PC_500b", CAV) #PC_50b
Bscale("pd.obs", "PC2_50a", "PC2_100a", "PC2_250a", "PC2_500a", CAV) #PC2_50a
Bscale("pd.obs", "PC2_50b", "PC2_100b", "PC2_250b", "PC2_500b", CAV) #PC2_500b
Bscale("pd.obs", "BPA_50", "BPA_100", "BPA_250", "BPA_500", CAV) #BPA_50
Bscale("pd.obs", "FOREST_50", "FOREST_100", "FOREST_250", "FOREST_500", CAV) ##FOREST_50
Bscale("pd.obs", "MINING_50", "MINING_100", "MINING_250", "MINING_500", CAV) ##MINING_250
Bscale("pd.obs", "MONTSAV_50", "MONTSAV_100", "MONTSAV_250", "MONTSAV_500", CAV) ##MONTSAV_50

PD <- lmer(pd.obs ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
               scale(DCL_0_10B250, scale=T) + scale(DCL_10_20B100, scale=T) + scale(DCL_20_30B250, scale=T) + scale(DCL_30_40B500, scale=T) +
               scale(dens_50_km2, scale=T) + scale(PC_100a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_500b, scale=T) +
               scale(BPA_50, scale=T) + scale(FOREST_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + (1|Highland), data=CAV, REML=F)

max.r(PD)
COR <- abs(cov2cor(vcov(PD))) ##Removed: scale(FOREST_50, scale=T) , scale(DCL_10_20B100, scale=T) 
COR>=0.8&COR<1

PD2 <- lmer(pd.obs ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
             scale(DCL_0_10B250, scale=T) + scale(DCL_20_30B250, scale=T) + scale(DCL_30_40B500, scale=T) +
             scale(dens_50_km2, scale=T) + scale(PC_100a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_500b, scale=T) +
             scale(BPA_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + (1|Highland), data=CAV, REML=F)

max.r(PD2) #Omitted (r=0.61)
COR <- abs(cov2cor(vcov(PD2))) ##
COR>=0.6&COR<1

##Add Cave variables
PD_cave <- lmer(pd.obs ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
              scale(DCL_0_10B250, scale=T) + scale(DCL_20_30B250, scale=T) + scale(DCL_30_40B500, scale=T) +
              scale(dens_50_km2, scale=T) + scale(PC_100a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_500b, scale=T) +
              scale(BPA_50, scale=T) + scale(MINING_250, scale=T) + scale(MONTSAV_50, scale=T) + 
              scale(Altitude, scale=T) + scale(Area, scale=T)  + PW  + WR + Det + Guano + Ofez + (1|Highland), data=CAV, REML=F)

max.r(PD_cave)
drop1(PD_cave, test="Chisq") ##

PD.bm <- lmer(pd.obs ~ scale(dist_dreinage, scale = T) + scale(area_vs_buff50, scale = T) + scale(PC_50b, scale = T) + scale(BPA_50, scale = T) + scale(Area, scale = T) + Guano +
                (1|Highland), data=CAV, REML=T)

summary(PD.bm)
biplot(PC_50); loadings(PC_50)

###################################################################### Rarity-weighted richness
CAV$Wrich.log <- log(CAV$Wrich)

##Landscape Vars
Bscale("Wrich.log", "area_vs_buff50", "area_vs_buff100", "area_vs_buff250", "area_vs_buff500", CAV) #area_vs_buff50
Bscale("Wrich.log", "DCL_0_10B50", "DCL_0_10B100", "DCL_0_10B250", "DCL_0_10B500", CAV) #DCL_0_10B50
Bscale("Wrich.log", "DCL_10_20B50", "DCL_10_20B100", "DCL_10_20B250", "DCL_10_20B500", CAV) #DCL_10_20B50
Bscale("Wrich.log", "DCL_20_30B50", "DCL_20_30B100", "DCL_20_30B250", "DCL_20_30B500", CAV) #DCL_20_30B500
Bscale2("Wrich.log", "DCL_30_40B250", "DCL_30_40B500", CAV) #DCL_30_40B250
Bscale("Wrich.log", "dens_50_km2", "dens_100_km2", "dens_250_km2", "dens_500_km2", CAV) #dens_50_km2
Bscale("Wrich.log", "PC_50a", "PC_100a", "PC_250a", "PC_500a", CAV) #PC_500a
Bscale("Wrich.log", "PC_50b", "PC_100b", "PC_250b", "PC_500b", CAV) #PC_50b
Bscale("Wrich.log", "PC2_50a", "PC2_100a", "PC2_250a", "PC2_500a", CAV) #PC2_50a
Bscale("Wrich.log", "PC2_50b", "PC2_100b", "PC2_250b", "PC2_500b", CAV) #PC2_500b
Bscale("Wrich.log", "BPA_50", "BPA_100", "BPA_250", "BPA_500", CAV) #BPA_50
Bscale("Wrich.log", "FOREST_50", "FOREST_100", "FOREST_250", "FOREST_500", CAV) ##FOREST_50
Bscale("Wrich.log", "MINING_50", "MINING_100", "MINING_250", "MINING_500", CAV) ##MINING_500
Bscale("Wrich.log", "MONTSAV_50", "MONTSAV_100", "MONTSAV_250", "MONTSAV_500", CAV) ##MONTSAV_50

WR <- lmer(Wrich.log ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
             scale(DCL_0_10B50, scale=T) + scale(DCL_10_20B50, scale=T) + scale(DCL_20_30B500, scale=T) + scale(DCL_30_40B250, scale=T) +
             scale(dens_50_km2, scale=T) + scale(PC_500a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + scale(PC2_500b, scale=T) +
             scale(BPA_50, scale=T) + scale(FOREST_50, scale=T) + scale(MINING_500, scale=T) + scale(MONTSAV_50, scale=T) + (1|Highland), data=CAV, REML=F)

max.r(WR)
COR <- abs(cov2cor(vcov(WR))) ##Removed: scale(FOREST_50, scale=T), scale(DCL_10_20B50, scale=T), scale(PC2_500b, scale=T) +
COR>=0.9&COR<1

WR2 <- lmer(Wrich.log ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
              scale(DCL_0_10B50, scale=T) + scale(DCL_20_30B500, scale=T) + scale(DCL_30_40B250, scale=T) +
              scale(dens_50_km2, scale=T) + scale(PC_500a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + 
              scale(BPA_50, scale=T) + scale(MINING_500, scale=T) + scale(MONTSAV_50, scale=T) + (1|Highland), data=CAV, REML=F)

max.r(WR2) #O
COR <- abs(cov2cor(vcov(WR2))) ##
COR>=0.8&COR<1

##Add Cave variables
WR_cave <- lmer(Wrich.log ~ scale(dist_dreinage, scale=T) + scale(area_vs_buff50, scale=T) + 
                  scale(DCL_0_10B50, scale=T) + scale(DCL_20_30B500, scale=T) + scale(DCL_30_40B250, scale=T) +
                  scale(dens_50_km2, scale=T) + scale(PC_500a, scale=T) + scale(PC_50b, scale=T) + scale(PC2_50a, scale=T) + 
                  scale(BPA_50, scale=T) + scale(MINING_500, scale=T) + scale(MONTSAV_50, scale=T) + 
                  scale(Altitude, scale=T) + scale(Area, scale=T)  + PW  + WR + Det + Guano + Ofez + (1|Highland), data=CAV, REML=F)

max.r(WR_cave)
drop1(WR_cave, test="Chisq") ##

WR.bm <- lmer(Wrich.log ~ scale(dist_dreinage, scale = T) + scale(PC_50b, scale = T) + scale(MONTSAV_50, scale = T) + scale(Area, scale = T) + Guano +
                (1|Highland), data=CAV, REML=T)

summary(WR.bm)
########################### FINAL MODELS
Com1.F <- lmer(MDS1 ~ scale(area_vs_buff500, scale=T) + scale(DCL_0_10B500, scale = T) + scale(MINING_250, scale = T) + (1|Highland), data=CAV, REML=T)

Com2.F <- lmer(MDS2 ~ scale(DCL_30_40B500, scale = T) + scale(dens_50_km2, scale = T) + scale(PC2_50b, scale = T) + scale(MONTSAV_50, scale = T) + 
                  scale(Altitude, scale = T) + (1|Highland), data=CAV, REML=T)

cont=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))
Rich.F <- glmer(TrogRich ~ scale(dist_dreinage, scale = T) + scale(PC_50b, scale = T) + scale(BPA_50, scale = T) + scale(Area, scale = T) + Guano +
                   (1|Highland) + (1|ID), data=CAV, family="poisson", control=cont)

PD.F <- lmer(pd.obs ~ scale(dist_dreinage, scale = T) + scale(area_vs_buff50, scale = T) + scale(PC_50b, scale = T) + scale(BPA_50, scale = T) + scale(Area, scale = T) + Guano +
                (1|Highland), data=CAV, REML=T)

WR.F <- lmer(Wrich.log ~ scale(dist_dreinage, scale = T) + scale(PC_50b, scale = T) + scale(MONTSAV_50, scale = T) + scale(Area, scale = T) + Guano +
               (1|Highland), data=CAV, REML=T)

write.csv(summary(Com1.F)$coefficients, file="Com1_summary.csv", row.names=T)
write.csv(summary(Com2.F)$coefficients, file="Com2_summary.csv", row.names=T)
write.csv(summary(Rich.F)$coefficients, file="Rich_summary.csv", row.names=T)
write.csv(summary(PD.F)$coefficients, file="PD_summary.csv", row.names=T)
write.csv(summary(WR.F)$coefficients, file="WR_summary.csv", row.names=T)

############################################### Model validation
CAV$RES1 <- resid(Com1.F)
CAV$RES2 <- resid(Com2.F)
CAV$RES3 <- resid(Rich.F)
CAV$RES4 <- resid(PD.F)
CAV$RES5 <- resid(WR.F)

plot(predict(Com1.F), CAV$RES1); abline(0,0, col="red")
plot(predict(Com2.F), CAV$RES2); abline(0,0, col="red")
plot(predict(Rich.F), CAV$RES3); abline(0,0, col="red")
plot(predict(PD.F), CAV$RES4); abline(0,0, col="red")
plot(predict(WR.F), CAV$RES5); abline(0,0, col="red")

qqnorm(CAV$RES1); qqline(CAV$RES1, col="red")
qqnorm(CAV$RES2); qqline(CAV$RES2, col="red")
qqnorm(CAV$RES3); qqline(CAV$RES3, col="red")
qqnorm(CAV$RES4); qqline(CAV$RES4, col="red")
qqnorm(CAV$RES5); qqline(CAV$RES5, col="red")

########## Spatial autocorrelation of residuals
acf(CAV$RES1) 
acf(CAV$RES2) 
acf(CAV$RES3) 
acf(CAV$RES4) 
acf(CAV$RES5) 

######Moran's I
library(spdep); library(sp); library(geosphere)

CAV2 <- CAV
CAV2$RES1 <- resid(Com1.F)
CAV2$RES2 <- resid(Com2.F)
CAV2$RES3 <- resid(Rich.F)
CAV2$RES4 <- resid(PD.F)
CAV2$RES5 <- resid(WR.F)
coordinates(CAV2) <- c(3:4)
proj4string(CAV2) <- CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +units=m")

r.nb <- dnearneigh(CAV2, 0, 5, row.names = CAV2$ID) 
moran.test(CAV2$RES1, listw=nb2listw(r.nb, style="W")) ##No SA
moran.mc(CAV2$RES1, listw=nb2listw(r.nb, style="W"), nsim=999)

moran.test(CAV2$RES2, listw=nb2listw(r.nb, style="W")) ##No SA
moran.mc(CAV2$RES2, listw=nb2listw(r.nb, style="W"), nsim=999)

moran.test(CAV2$RES3, listw=nb2listw(r.nb, style="W")) ##No SA
moran.mc(CAV2$RES3, listw=nb2listw(r.nb, style="W"), nsim=999)

moran.test(CAV2$RES4, listw=nb2listw(r.nb, style="W")) ##No SA
moran.mc(CAV2$RES4, listw=nb2listw(r.nb, style="W"), nsim=999)

moran.test(CAV2$RES5, listw=nb2listw(r.nb, style="W")) ##No SA
moran.mc(CAV2$RES5, listw=nb2listw(r.nb, style="W"), nsim=999)

##### Effect plots
library(effects)

Com1.AE <- lmer(MDS1 ~ area_vs_buff500 + DCL_0_10B500 + MINING_250 + (1|Highland), data=CAV, REML=T)

Com2.AE <- lmer(MDS2 ~ DCL_30_40B500 + dens_50_km2 + PC2_50b + MONTSAV_50 +  Altitude + (1|Highland), data=CAV, REML=T) 

cont=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=100000))
Rich.AE <- glmer(TrogRich ~ dist_dreinage + PC_50b + BPA_50 + Area + Guano +
                   (1|Highland) + (1|ID), data=CAV, family="poisson", control=cont)

PD.AE <- lmer(pd.obs ~ dist_dreinage + area_vs_buff50 + PC_50b + BPA_50 + Area + Guano +
                (1|Highland), data=CAV, REML=T)

WR.AE <- lmer(Wrich.log ~ dist_dreinage + PC_50b + MONTSAV_50 + Area + Guano +
                (1|Highland), data=CAV, REML=T)

AE <- allEffects(Com1.AE)
plot(AE)

AE2 <- allEffects(Com2.AE)
plot(AE2)

AE3 <- allEffects(Rich.AE)
plot(AE3)

AE4 <- allEffects(PD.AE)
plot(AE4)

AE5 <- allEffects(WR.AE)
plot(AE5)

plot(AE3[1], xlab="DIstance to creek (m)", ylab="Species richness", main=NULL)

################################# Scales
#Com1.F: MINING_250
#Com2.F: MONTSAV_50
#Rich.F BPA_50
#PD.F: BPA_50
#WR.F: MONTSAV_50

MS_Com1 <- Bscale("MDS1", "MINING_50", "MINING_100", "MINING_250", "MINING_500", CAV) 
MS_Com2 <- Bscale("MDS2", "MONTSAV_50", "MONTSAV_100", "MONTSAV_250", "MONTSAV_500", CAV) 
MS_Rich <- Bscale.glm("TrogRich", "BPA_50", "BPA_100", "BPA_250", "BPA_500", CAV) 
MS_PD <- Bscale("pd.obs", "BPA_50", "BPA_100", "BPA_250", "BPA_500", CAV) 
MS_WR <- Bscale("Wrich.log", "MONTSAV_50", "MONTSAV_100", "MONTSAV_250", "MONTSAV_500", CAV) 

MS_Com1 <- as.data.frame(MS_Com1)
MS_Com2 <- as.data.frame(MS_Com2)
MS_Rich <- as.data.frame(MS_Rich)
MS_PD <- as.data.frame(MS_PD)
MS_WR <- as.data.frame(MS_WR)


MS_Com1$Scale <- row.names(MS_Com1)
MS_Com1$Scale2 <- ifelse(MS_Com1$Scale=="M4", 500, ifelse(MS_Com1$Scale=="M3", 250, ifelse(MS_Com1$Scale=="M2", 100, 50)))
MS_Com1$Scale2 <- as.factor(MS_Com1$Scale2)
MS_Com1$LU <- rep("Mining", 4)

MS_Com2$Scale <- row.names(MS_Com2)
MS_Com2$Scale2 <- ifelse(MS_Com2$Scale=="M4", 500, ifelse(MS_Com2$Scale=="M3", 250, ifelse(MS_Com2$Scale=="M2", 100, 50)))
MS_Com2$Scale2 <- as.factor(MS_Com2$Scale2)
MS_Com2$LU <- rep("Canga", 4)

MS_Rich$Scale <- row.names(MS_Rich)
MS_Rich$Scale2 <- ifelse(MS_Rich$Scale=="M4", 500, ifelse(MS_Rich$Scale=="M3", 250, ifelse(MS_Rich$Scale=="M2", 100, 50)))
MS_Rich$Scale2 <- as.factor(MS_Rich$Scale2)
MS_Rich$LU <- rep("Agriculture", 4)

MS_PD$Scale <- row.names(MS_PD)
MS_PD$Scale2 <- ifelse(MS_PD$Scale=="M4", 500, ifelse(MS_PD$Scale=="M3", 250, ifelse(MS_PD$Scale=="M2", 100, 50)))
MS_PD$Scale2 <- as.factor(MS_PD$Scale2)
MS_PD$LU <- rep("Agriculture", 4)

MS_WR$Scale <- row.names(MS_WR)
MS_WR$Scale2 <- ifelse(MS_WR$Scale=="M4", 500, ifelse(MS_WR$Scale=="M3", 250, ifelse(MS_WR$Scale=="M2", 100, 50)))
MS_WR$Scale2 <- as.factor(MS_WR$Scale2)
MS_WR$LU <- rep("Canga", 4)

### Plots
library(ggplot2)
library(gridExtra)

Pcom1 <- ggplot(MS_Com1, aes(x=Scale2, y=AIC, group = 1)) + geom_point() + geom_line(lwd=2) +
  #ggtitle(unique(MS_Com1$LU)) +
  ylab("AIC\n(Species composition - MDS1)") + annotate("text",x=c(3),y=c(814),label=c("Mining area"), size=5) +
  xlab(NULL) +  
  theme_minimal() + theme(plot.title = element_text(size=15, face="bold", hjust=0.5),
                          axis.title.x = element_text(size=20, color = "black", face = "bold"),
                          axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.text.x=element_blank())

Pcom2 <- ggplot(MS_Com2, aes(x=Scale2, y=AIC, group = 1)) + geom_point() + geom_line(lwd=2) +
  #ggtitle(unique(MS_Com2$LU)) +
  ylab("AIC\n(Species composition - MDS2)") + annotate("text",x=c(3),y=c(686.5),label=c("Canga area"), size=5) +
  xlab(NULL) +  
  theme_minimal() + theme(plot.title = element_text(size=15, face="bold", hjust=0.5),
                          axis.title.x = element_text(size=20, color = "black", face = "bold"),
                          axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.text.x=element_blank())

Prich <- ggplot(MS_Rich, aes(x=Scale2, y=AIC, group = 1)) + geom_point() + geom_line(lwd=2) +
  #ggtitle(unique(MS_Rich$LU)) +
  ylab("AIC\n(Specis richness)") + annotate("text",x=c(2),y=c(1986),label=c("Agriculture area"), size=5) +
  xlab(NULL) +  
  theme_minimal() + theme(plot.title = element_text(size=15, face="bold", hjust=0.5),
                          axis.title.x = element_text(size=20, color = "black", face = "bold"),
                          axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.text.x=element_blank())

Ppd <- ggplot(MS_PD, aes(x=Scale2, y=AIC, group = 1)) + geom_point() + geom_line(lwd=2) +
  #ggtitle(unique(MS_PD$LU)) +
  ylab("AIC\n(Phylogenetic diversity") + annotate("text",x=c(2),y=c(7864),label=c("Agriculture area"), size=5) +
  xlab("Scale (m)") +  
  theme_minimal() + theme(plot.title = element_text(size=15, face="bold", hjust=0.5),
                          axis.title.x = element_text(size=20, color = "black", face = "bold"),
                          axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.text.x = element_text(size=15, color = "black", face = "bold"))

Pwr <- ggplot(MS_WR, aes(x=Scale2, y=AIC, group = 1)) + geom_point() + geom_line(lwd=2) +
  #ggtitle(unique(MS_Com2$LU)) +
  ylab("AIC\n(Rarity-weighted richness)") + annotate("text",x=c(3),y=c(1736),label=c("Canga area"), size=5) +
  xlab(NULL) +  
  theme_minimal() + theme(plot.title = element_text(size=15, face="bold", hjust=0.5),
                          axis.title.x = element_text(size=20, color = "black", face = "bold"),
                          axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.text.x=element_blank())

grid.arrange(Pcom1, Pcom2, Prich, Pwr, Ppd, ncol=1)

tiff(filename = "AICplots.tif",
     width = 20, height = 35, units = "cm",
     compression = "lzw", bg = "white", res = 300)

grid.arrange(Pcom1, Pcom2, Prich, Pwr, Ppd, ncol=1)
dev.off()

