
###########################################################################################################################################
################################################################ Occurrence models ##########################################################
###########################################################################################################################################

############################################################################### Load data
Pdata <- read.csv("Occurrence_data.csv",head=T) 
Pdata <- Pdata[complete.cases(Pdata), ]
summary(Pdata)  ##Exclude Veg, Root, RB, Car, BATPOP
names(Pdata)

table(Pdata[, 31], Pdata$PW) ##Exclude PW
table(Pdata[, 31], Pdata$Det) ##Exclude Det

###Presence models loop
names(Pdata)
SP <- names(Pdata[, 28:41])
PModels <- list()

for(i in 1:length(SP)){
  Y <- as.name(SP[i])
  full <- paste(Y, "~", "Altitude", "+", "Slope", "+", "Area", "+", "WR", "+", "Guano", "+", "Ofez")
  P1 <- glm(full, data=Pdata, family=binomial)
  DRP <- drop1(P1, test="Chisq")
  DRP <- as.data.frame(DRP)
  PRED <- DRP[DRP$`Pr(>Chi)`<=0.05, ]
  PRED <- PRED[complete.cases(PRED), ]
  if(nrow(PRED)==7){
    formula <- paste(Y, "~", as.name(row.names(PRED)[1]), "+", as.name(row.names(PRED)[2]), "+", as.name(row.names(PRED)[3]), 
                     "+", as.name(row.names(PRED)[4]), "+", as.name(row.names(PRED)[5]), "+", as.name(row.names(PRED)[6]), "+", as.name(row.names(PRED)[7]))
    
  }else if(nrow(PRED)==6){
    formula <- paste(Y, "~", as.name(row.names(PRED)[1]), "+", as.name(row.names(PRED)[2]), "+", as.name(row.names(PRED)[3]), 
                     "+", as.name(row.names(PRED)[4]), "+", as.name(row.names(PRED)[5]), "+", as.name(row.names(PRED)[6]))
    
  }else if(nrow(PRED)==5){
    formula <- paste(Y, "~", as.name(row.names(PRED)[1]), "+", as.name(row.names(PRED)[2]), "+", as.name(row.names(PRED)[3]), 
                     "+", as.name(row.names(PRED)[4]), "+", as.name(row.names(PRED)[5]))
    
  }else if(nrow(PRED)==4){
    formula <- paste(Y, "~", as.name(row.names(PRED)[1]), "+", as.name(row.names(PRED)[2]), "+", as.name(row.names(PRED)[3]), 
                     "+", as.name(row.names(PRED)[4]))
    
  }else if(nrow(PRED)==3){
    formula <- paste(Y, "~", as.name(row.names(PRED)[1]), "+", as.name(row.names(PRED)[2]), "+", as.name(row.names(PRED)[3]))
    
  }else if(nrow(PRED)==2){
    formula <- paste(Y, "~", as.name(row.names(PRED)[1]), "+", as.name(row.names(PRED)[2]))
    
  }else if(nrow(PRED)==1){
    formula <- paste(Y, "~", as.name(row.names(PRED)[1]))
    
  }else{
    formula <- paste(Y, "~", 1)
  }
  
  BM <- glm(formula, family=binomial, data=Pdata)
  PModels[[i]] <- BM
}

Tables <- list()

for(i in 1:length(SP)){
SP_name <- SP[i]
COEF <- data.frame(Estimates=coefficients(PModels[[i]]))
COEF$Species <- rep(SP_name, nrow(COEF))
Tables[[i]] <- COEF
}

AllEstimates <- rbind(Tables[[1]], Tables[[2]], Tables[[3]], Tables[[4]],
      Tables[[5]], Tables[[6]], Tables[[7]], Tables[[8]],
      Tables[[9]], Tables[[10]], Tables[[11]], Tables[[12]],
      Tables[[13]], Tables[[14]])

length(unique(AllEstimates$Species))
write.csv(AllEstimates, file="AllEstimates2.csv", row.names=T)

###Check
PM1 <- glm(Matta_sp1 ~ Altitude + Slope + Area + WR + Guano + Ofez, data=Pdata, family=binomial)
drop1(PM1, test="Chisq")

###########################################Spatial autocorrelation
library(spdep)
library(sp)
library(geosphere)
library(raster)
library(ggplot2)

Pdata2 <- Pdata
coordinates(Pdata2) <- c(3:4)
proj4string(Pdata2) <- CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +units=m")
SP <- names(Pdata2@data[, c(26:39)])

##Joincount loop
Jdat_species <- function(k){
   
   Jdat <- data.frame(Dist=c(5:102), SCSn=rep(NA, 98), SCSy=rep(NA, 98), Expn=rep(NA, 98), Expy=rep(NA, 98), Varn=rep(NA, 98), Vary=rep(NA, 98), 
                     Sdn=rep(NA, 98), Sdy=rep(NA, 98), pn=rep(NA, 98), py=rep(NA, 98))
  for(i in 1:98){
    dmax<- Jdat$Dist[i]
    t.nb <- dnearneigh(Pdata2, 0, dmax, row.names = Pdata2$ID.y)
    Res <- try(joincount.test(Pdata2@data[, as.character(SP[k])], listw=nb2listw(t.nb, style="W")), silent=T) ##Only takes character data, no numbers
    SCSn <- as.numeric(Res[[1]]$estimate[1])
    print(paste0("Dist=", dmax, " - ", "Same colour statistic=", SCSn))
    SCSy <- as.numeric(Res[[2]]$estimate[1])
    Expn <- as.numeric(Res[[1]]$estimate[2])
    Expy <- as.numeric(Res[[2]]$estimate[2])
    Varn <- as.numeric(Res[[1]]$estimate[3])
    Vary <- as.numeric(Res[[2]]$estimate[3])
    Sdn <- as.numeric(Res[[1]]$statistic)
    Sdy <- as.numeric(Res[[2]]$statistic)
    pn <- as.numeric(Res[[1]]$p.value)
    py <- as.numeric(Res[[2]]$p.value)
    Jdat[i,2] <- SCSn
    Jdat[i,3] <- SCSy
    Jdat[i,4] <- Expn
    Jdat[i,5] <- Expy
    Jdat[i,6] <- Varn
    Jdat[i,7] <- Vary
    Jdat[i,8] <- Sdn
    Jdat[i,9] <- Sdy
    Jdat[i,10] <- pn
    Jdat[i,11] <- py
  }
  
##Save file
  name <- paste0("Jdat_", SP[k], ".csv")
  write.csv(Jdat, file=name, row.names=F)
}

  
for(i in 1:length(SP)){
  Jdat_species(i)
}


##Plots
Jdat_files <- list.files(pattern="Jdat")
Plots <- list()

for(i in 1:length(SP)){
Jdat <- read.csv(Jdat_files[i], head=T)
title <- unlist(strsplit(Jdat_files[i], "Jdat_"))
title2 <- title[2]
title3 <- unlist(strsplit(title2, ".csv"))
Jdat$CI.up <- Jdat$SCSy+(1.96*(sqrt(Jdat$Vary)))
Jdat$CI.low <- Jdat$SCSy-(1.96*(sqrt(Jdat$Vary)))

  Plots[[i]] <- ggplot(Jdat, aes(x=(Dist), y=SCSy)) + geom_line() + 
    #geom_vline(xintercept = Cut, linetype="dashed") + 
    geom_hline(yintercept = Jdat$Expy, linetype="dashed") + 
    geom_ribbon(aes(ymin = CI.low, ymax = CI.up), alpha = 0.25) + #geom_rug(sides = "b", alpha = 0.05) +
    ggtitle(title3) +
    ylab("Single Color Statistic") +
    xlab("Distance (km)") + 
    theme_minimal() + theme(plot.title = element_text(size = 10, face = "bold"),
                            axis.title.y = element_text(size=12, color = "black"),
                            axis.title.x = element_text(size=12, color = "black"))
  
}

####
library(gridExtra)

##Save Tiff

tiff(filename = "~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Figs/AllPlots.tif",
       width = 30, height = 30, units = "cm",
       compression = "lzw", bg = "white", res = 300)
  
grid.arrange(Plots[[1]], Plots[[2]], Plots[[3]], Plots[[4]],
             Plots[[5]], Plots[[6]], Plots[[7]], Plots[[8]],
             Plots[[9]], Plots[[10]], Plots[[11]], Plots[[12]],
             Plots[[13]], Plots[[14]], SPO, ncol=4)

dev.off()

#######################################################################################################################################################################
###################################################################################### Rare troglobites ###############################################################
#######################################################################################################################################################################

##Transform DF into community matrix
library(reshape)
CM_df <- read.csv("Troglobites_taxa.csv", head=T)
CM_df2 <- cast(CM_df, CAVE.ID ~ Species, value="Count", sum) 
CM_df2 <- as.data.frame(CM_df2)
row.names(CM_df2) <- CM_df2$ID
head(CM_df2)

### Community matrix
names(CM_df2)
CM_df3 <- CM_df2[ , c(2:134)]
CM_df3 <- droplevels(CM_df3)
CM_df3[CM_df3 >= 1 ] <- 1 ## Dataframe: Transform abundance into presence/absence data
head(CM_df3)
ncol(CM_df3)

##Frequent species
CM_df4 <- CM_df3[ , colSums(CM_df3)>=20]
min(colSums(CM_df4))
names(CM_df4)

####### Histogram
hist(colSums(CM_df3), breaks=100)
hist(colSums(CM_df3), xlim=c(0,50), breaks=50)

N <- as.numeric(colSums(CM_df3))
N2 <- data.frame(NCaves=N)
head(N2)
table(N2$N)

library(ggplot2)

SPO <- ggplot(N2, aes(x=NCaves)) + geom_histogram(size=1.5, binwidth=1) + 
  #geom_vline(xintercept = Cut, linetype="dashed") + 
  xlab("Number of occurrences (caves)") + geom_vline(xintercept = 30, size = 1, linetype="dashed", col = "black") +
  ylab("Number of species") + 
  theme_minimal() + theme(text = element_text(size = 15, face = "bold"),
                          axis.title.y = element_text(size=15, color = "black", face = "bold"),
                          axis.title.x = element_text(size=15, color = "black", face = "bold"))

tiff(filename = "~/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Figs/Occ_hist.tif",
     width = 15, height = 15, units = "cm",
     compression = "lzw", bg = "white", res = 300)

SPO
dev.off()
