
library(spdep); library(sp); library(geosphere)

###Load data
CAV <- read.csv("TrogData_final_wr.csv", head=T, na.string="NA")
CAV <- CAV[complete.cases(CAV$Long, CAV$Lat), ]
CAV <- droplevels(CAV)
head(CAV)

coordinates(CAV) <- c(3:4)
proj4string(CAV) <- CRS("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs +units=m")

##Create neighbours object
max_dst <- max(distm(coordinates(CAV), fun = distHaversine)) #102995
min_dst <- min(distm(coordinates(CAV), fun = distHaversine)) #0
r.nb <- dnearneigh(CAV, 0, 25, row.names = CAV$ID) 
plot(r.nb, coordinates(CAV))

###### Tests
r.nb <- dnearneigh(CAV, 0, 5, row.names = CAV$ID) ##Threshold max value is 5
moran.test(CAV$TrogRich, listw=nb2listw(r.nb, style="W")) 
moran.mc(CAV$TrogRich, listw=nb2listw(r.nb, style="W"), nsim=999)
moran.plot(as.numeric(scale(CAV$TrogRich)), listw=nb2listw(r.nb, style="W")) 

################################## Iplots
#### Save Mdata after each loop
### Loop1: MDS1
Mdat <- data.frame(Dist=c(5:102), I=rep(NA, 98), Exp=rep(NA, 98), Var=rep(NA, 98), Sdev=rep(NA, 98), p=rep(NA, 98))

for(i in 1:98){
  dmax<- Mdat$Dist[i]
  r.nb <- dnearneigh(CAV, 0, dmax, row.names = CAV$ID)
  Res <- moran.test(CAV$MDS1, listw=nb2listw(r.nb, style="W")) 
  I <- as.numeric(Res$estimate[1])
  Exp <- as.numeric(Res$estimate[2])
  Var <- as.numeric(Res$estimate[3])
  Sdev <- as.numeric(Res$statistic)
  p <- Res$p.value 
  Mdat[i,2] <- I
  Mdat[i,3] <- Exp
  Mdat[i,4] <- Var
  Mdat[i,5] <- Sdev
  Mdat[i,6] <- p
}

head(Mdat)
tail(Mdat,15)
#write.csv(Mdat, file="Iplots/Mdat_MDS1.csv", col.names=T, row.names=F)

##I Plots
library(ggplot2)
Mdat <- read.csv("/home/rodolfo-ws/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Iplots/Mdat_MDS1.csv", header=T)
Mdat$CI.up <- Mdat$I+(1.96*(sqrt(Mdat$Var)))
Mdat$CI.low <- Mdat$I-(1.96*(sqrt(Mdat$Var)))
#Cut <- min(Mdat[Mdat$p>0.05,1])

Iplot_mds1 <- ggplot(Mdat, aes(x=(Dist), y=I)) + geom_line() + 
  #geom_vline(xintercept = Cut, linetype="dashed") + 
  geom_hline(yintercept = Mdat$Exp, linetype="dashed") + 
  geom_ribbon(aes(ymin = CI.low, ymax = CI.up), alpha = 0.25) + #geom_rug(sides = "b", alpha = 0.05) +
  ylab("Moran's I\n(Species composition - MDS1)") +
  xlab(NULL) + xlim(0,105) +
  theme_minimal() + theme(axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.title.x = element_text(size=15, color = "black", face = "bold"))
Iplot_mds1

### Loop2: MDS2
Mdat <- data.frame(Dist=c(5:102), I=rep(NA, 98), Exp=rep(NA, 98), Var=rep(NA, 98), Sdev=rep(NA, 98), p=rep(NA, 98))

for(i in 1:98){
  dmax<- Mdat$Dist[i]
  r.nb <- dnearneigh(CAV, 0, dmax, row.names = CAV$ID)
  Res <- moran.test(CAV$MDS2, listw=nb2listw(r.nb, style="W")) 
  I <- as.numeric(Res$estimate[1])
  Exp <- as.numeric(Res$estimate[2])
  Var <- as.numeric(Res$estimate[3])
  Sdev <- as.numeric(Res$statistic)
  p <- Res$p.value 
  Mdat[i,2] <- I
  Mdat[i,3] <- Exp
  Mdat[i,4] <- Var
  Mdat[i,5] <- Sdev
  Mdat[i,6] <- p
}

head(Mdat)
tail(Mdat,15)
#write.csv(Mdat, file="Iplots/Mdat_MDS2.csv", col.names=T, row.names=F)

##I Plots
library(ggplot2)
Mdat <- read.csv("/home/rodolfo-ws/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Iplots/Mdat_MDS2.csv", header=T)
Mdat$CI.up <- Mdat$I+(1.96*(sqrt(Mdat$Var)))
Mdat$CI.low <- Mdat$I-(1.96*(sqrt(Mdat$Var)))
#Cut <- min(Mdat[Mdat$p>0.05,1])

Iplot_mds2 <- ggplot(Mdat, aes(x=(Dist), y=I)) + geom_line() + 
  #geom_vline(xintercept = Cut, linetype="dashed") + 
  geom_hline(yintercept = Mdat$Exp, linetype="dashed") + 
  geom_ribbon(aes(ymin = CI.low, ymax = CI.up), alpha = 0.25) + #geom_rug(sides = "b", alpha = 0.05) +
  ylab("Moran's I\n(Species composition - MDS2)") +
  xlab(NULL) + xlim(0,105) +
  theme_minimal() + theme(axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.title.x = element_text(size=15, color = "black", face = "bold"))
Iplot_mds2 

### Loop3: TrogRich
Mdat <- data.frame(Dist=c(5:102), I=rep(NA, 98), Exp=rep(NA, 98), Var=rep(NA, 98), Sdev=rep(NA, 98), p=rep(NA, 98))

for(i in 1:98){
  dmax<- Mdat$Dist[i]
  r.nb <- dnearneigh(CAV, 0, dmax, row.names = CAV$ID)
  Res <- moran.test(CAV$TrogRich, listw=nb2listw(r.nb, style="W")) 
  I <- as.numeric(Res$estimate[1])
  Exp <- as.numeric(Res$estimate[2])
  Var <- as.numeric(Res$estimate[3])
  Sdev <- as.numeric(Res$statistic)
  p <- Res$p.value 
  Mdat[i,2] <- I
  Mdat[i,3] <- Exp
  Mdat[i,4] <- Var
  Mdat[i,5] <- Sdev
  Mdat[i,6] <- p
}

head(Mdat)
tail(Mdat,15)
#write.csv(Mdat, file="Iplots/Mdat_TrogRich.csv", col.names=T, row.names=F)

##I Plots
library(ggplot2)
Mdat <- read.csv("/home/rodolfo-ws/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Iplots/Mdat_TrogRich.csv", header=T)
Mdat$CI.up <- Mdat$I+(1.96*(sqrt(Mdat$Var)))
Mdat$CI.low <- Mdat$I-(1.96*(sqrt(Mdat$Var)))
#Cut <- min(Mdat[Mdat$p>0.05,1])

Iplot_trogrich <- ggplot(Mdat, aes(x=(Dist), y=I)) + geom_line() + 
  #geom_vline(xintercept = Cut, linetype="dashed") + 
  geom_hline(yintercept = Mdat$Exp, linetype="dashed") + 
  geom_ribbon(aes(ymin = CI.low, ymax = CI.up), alpha = 0.25) + #geom_rug(sides = "b", alpha = 0.05) +
  ylab("Moran's I\n(Species richness)") +
  xlab(NULL) + xlim(0,105) +
  theme_minimal() + theme(axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.title.x = element_text(size=15, color = "black", face = "bold"))
Iplot_trogrich 


### Loop4: PHyloDiv
Mdat <- data.frame(Dist=c(5:102), I=rep(NA, 98), Exp=rep(NA, 98), Var=rep(NA, 98), Sdev=rep(NA, 98), p=rep(NA, 98))

for(i in 1:98){
  dmax<- Mdat$Dist[i]
  r.nb <- dnearneigh(CAV, 0, dmax, row.names = CAV$ID)
  Res <- moran.test(CAV$pd.obs, listw=nb2listw(r.nb, style="W")) 
  I <- as.numeric(Res$estimate[1])
  Exp <- as.numeric(Res$estimate[2])
  Var <- as.numeric(Res$estimate[3])
  Sdev <- as.numeric(Res$statistic)
  p <- Res$p.value 
  Mdat[i,2] <- I
  Mdat[i,3] <- Exp
  Mdat[i,4] <- Var
  Mdat[i,5] <- Sdev
  Mdat[i,6] <- p
}

head(Mdat)
tail(Mdat,15)
#write.csv(Mdat, file="Iplots/Mdat_pd.csv", col.names=T, row.names=F)

##I Plots
library(ggplot2)
Mdat <- read.csv("/home/rodolfo-ws/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Iplots/Mdat_pd.csv", header=T)
Mdat$CI.up <- Mdat$I+(1.96*(sqrt(Mdat$Var)))
Mdat$CI.low <- Mdat$I-(1.96*(sqrt(Mdat$Var)))
#Cut <- min(Mdat[Mdat$p>0.05,1])

Iplot_pd <- ggplot(Mdat, aes(x=(Dist), y=I)) + geom_line() + 
  #geom_vline(xintercept = Cut, linetype="dashed") + 
  geom_hline(yintercept = Mdat$Exp, linetype="dashed") + 
  geom_ribbon(aes(ymin = CI.low, ymax = CI.up), alpha = 0.25) + #geom_rug(sides = "b", alpha = 0.05) +
  ylab("Moran's I\n(Phylogenetic diversity)") +
  xlab("Distance (km)") + xlim(0,105) +
  theme_minimal() + theme(axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.title.x = element_text(size=15, color = "black", face = "bold"))
Iplot_pd 

### Loop5: Weighted Richness
Mdat <- data.frame(Dist=c(5:102), I=rep(NA, 98), Exp=rep(NA, 98), Var=rep(NA, 98), Sdev=rep(NA, 98), p=rep(NA, 98))

for(i in 1:98){
  dmax<- Mdat$Dist[i]
  r.nb <- dnearneigh(CAV, 0, dmax, row.names = CAV$ID)
  Res <- moran.test(CAV$Wrich, listw=nb2listw(r.nb, style="W")) 
  I <- as.numeric(Res$estimate[1])
  Exp <- as.numeric(Res$estimate[2])
  Var <- as.numeric(Res$estimate[3])
  Sdev <- as.numeric(Res$statistic)
  p <- Res$p.value 
  Mdat[i,2] <- I
  Mdat[i,3] <- Exp
  Mdat[i,4] <- Var
  Mdat[i,5] <- Sdev
  Mdat[i,6] <- p
}

head(Mdat)
tail(Mdat,15)
#write.csv(Mdat, file="/home/rodolfo-ws/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Iplots/Mdat_Wrich.csv", col.names=T, row.names=F)

##I Plots
library(ggplot2)
Mdat <- read.csv("/home/rodolfo-ws/Dropbox/Rodolfo/ITV/Troglobios/R/Troglobites/Iplots/Mdat_Wrich.csv", header=T)
Mdat$CI.up <- Mdat$I+(1.96*(sqrt(Mdat$Var)))
Mdat$CI.low <- Mdat$I-(1.96*(sqrt(Mdat$Var)))
#Cut <- min(Mdat[Mdat$p>0.05,1])

Iplot_Wrich <- ggplot(Mdat, aes(x=(Dist), y=I)) + geom_line() + 
  #geom_vline(xintercept = Cut, linetype="dashed") + 
  geom_hline(yintercept = Mdat$Exp, linetype="dashed") + 
  geom_ribbon(aes(ymin = CI.low, ymax = CI.up), alpha = 0.25) + #geom_rug(sides = "b", alpha = 0.05) +
  ylab("Moran's I\n(Rarity-weighted richness)") +
  xlab(NULL) + xlim(0,105) +
  theme_minimal() + theme(axis.title.y = element_text(size=12, color = "black", face = "bold"),
                          axis.title.x = element_text(size=15, color = "black", face = "bold"))
Iplot_Wrich

##### Final Plot
library(gridExtra)

tiff(filename = "Iplots.tif",
     width = 20, height = 35, units = "cm",
     compression = "lzw", bg = "white", res = 300)

grid.arrange(Iplot_mds1, Iplot_mds2, Iplot_trogrich, Iplot_Wrich, Iplot_pd, ncol=1)
dev.off()
